@@ -19,8 +19,9 @@
  */
 
 
-#define MCRYPT_API_VERSION 20020309
-#define LIBMCRYPT_VERSION "2.5.3"
+#define MCRYPT_API_VERSION 20021217
+
+#define LIBMCRYPT_VERSION "2.5.5"
 
 #ifdef __cplusplus
 extern "C" {
@@ -39,6 +40,10 @@ typedef struct CRYPT_STREAM *MCRYPT;
 				  char *m_directory);
 	int mcrypt_module_close(MCRYPT td);
 
+	/* returns 0 if the library has not been compiled with
+	 * dynamic module support.
+ 	 */
+	int mcrypt_module_support_dynamic(void);
 
 /* returns thread descriptor */
 
