@@ -7,7 +7,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: blowfish-compat.c,v 1.9 2002/03/09 20:29:03 nmav Exp $ */
+/* $Id: blowfish-compat.c,v 1.10 2002/10/01 11:26:47 nmav Exp $ */
 
 #include <libdefs.h>
 
@@ -655,3 +655,10 @@ WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
 	return 20010801;
 }
+
+#ifdef WIN32
+WIN32DLL_DEFINE int main (void)
+{
+       /* empty main function to avoid linker error (see cygwin FAQ) */
+}
+#endif
