@@ -1,6 +1,6 @@
 /* panama_x.c */
 
-/* $Id: panama.c,v 1.19 2002/05/24 06:15:00 nmav Exp $ */
+/* $Id: panama.c,v 1.20 2002/10/01 11:26:47 nmav Exp $ */
 
 /* daemen.j@protonworld.com */
 /**************************************************************************+
@@ -689,3 +689,10 @@ WIN32DLL_DEFINE word32 _mcrypt_algorithm_version(void)
 {
 	return 20010801;
 }
+
+#ifdef WIN32
+WIN32DLL_DEFINE int main (void)
+{
+       /* empty main function to avoid linker error (see cygwin FAQ) */
+}
+#endif
