@@ -13,7 +13,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rc2.c,v 1.12 2002/03/09 20:29:04 nmav Exp $ */
+/* $Id: rc2.c,v 1.13 2002/10/01 11:26:47 nmav Exp $ */
 
 #include <libdefs.h>
 
@@ -312,3 +312,10 @@ WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
 	return 20010801;
 }
+
+#ifdef WIN32
+WIN32DLL_DEFINE int main (void)
+{
+       /* empty main function to avoid linker error (see cygwin FAQ) */
+}
+#endif
