@@ -16,7 +16,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: tripledes.c,v 1.11 2002/03/09 20:29:04 nmav Exp $ */
+/* $Id: tripledes.c,v 1.12 2002/10/01 11:26:47 nmav Exp $ */
 
 #include <libdefs.h>
 #include <mcrypt_modules.h>
@@ -848,3 +848,10 @@ WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
 	return 19991129;
 }
+
+#ifdef WIN32
+WIN32DLL_DEFINE int main (void)
+{
+       /* empty main function to avoid linker error (see cygwin FAQ) */
+}
+#endif
