@@ -20,7 +20,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: twofish.c,v 1.14 2002/05/26 11:15:05 nmav Exp $ */
+/* $Id: twofish.c,v 1.15 2002/10/01 11:26:47 nmav Exp $ */
 
 /* Timing data for Twofish (twofish.c)
 
@@ -664,3 +664,10 @@ WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
 	return 19991129;
 }
+
+#ifdef WIN32
+WIN32DLL_DEFINE int main (void)
+{
+       /* empty main function to avoid linker error (see cygwin FAQ) */
+}
+#endif
