@@ -320,3 +320,10 @@ int _mcrypt_mode_get_size () {return sizeof(nCFB_BUFFER);}
 word32 _mcrypt_mode_version() {
 	return 20020307;
 }
+
+#ifdef WIN32
+WIN32DLL_DEFINE int main (void)
+{
+       /* empty main function to avoid linker error (see cygwin FAQ) */
+}
+#endif
