@@ -73,3 +73,10 @@ int _mcrypt_mode_get_size () {return 0;}
 word32 _mcrypt_mode_version() {
 	return 20010801;
 }
+
+#ifdef WIN32
+WIN32DLL_DEFINE int main (void)
+{
+       /* empty main function to avoid linker error (see cygwin FAQ) */
+}
+#endif
